# URPy ![version](https://img.shields.io/badge/version-1.0.0-blue.svg)
A module to make your life easier when communicating with a Universal Robot from python.

## Download
- [Latest release](https://github.com/JonasAlmaas/urpy/releases/latest)
- [All releases](https://github.com/JonasAlmaas/urpy/releases)

## Getting started
Download the [latest release](https://github.com/JonasAlmaas/prop-combine-tools/releases/latest) and copy its content into your project. For examles on how to use the modulde look inside the <strong>scripts</strong> folder on github.

## Additional Information
Go to Internet Protocol Verson 4 (TCP/IPv4) under Ethernet properties. Set it to use manual IP, make sure the subnet mask is set to <strong>255.255.255.0</strong>. Also set the DNS server manual. Perfered DNS server should be <strong>10.234.32.10</strong> and Alternate DNS server should be <strong>10.234.32.11</strong>.
